@@ -18,14 +18,13 @@
  */
 
 #include "abstractrunner.h"
+#include "abstractrunner_p.h"
 
 #include <QAction>
+#include <QElapsedTimer>
 #include <QHash>
-#include <QMenu>
 #include <QMimeData>
 #include <QMutex>
-#include <QMutexLocker>
-#include <QTimer>
 
 #include "krunner_debug.h"
 #include <kplugininfo.h>
@@ -35,7 +34,6 @@
 #include <Plasma/PluginLoader>
 #include <qstandardpaths.h>
 
-#include "abstractrunner_p.h"
 #include "querymatch.h"
 #include "runnercontext.h"
 
@@ -60,7 +58,7 @@ AbstractRunner::AbstractRunner(QObject *parent, const QVariantList &args)
     : QObject(parent),
       d(new AbstractRunnerPrivate(this))
 {
-    if (args.count() > 0) {
+    if (!args.isEmpty()) {
         KService::Ptr service = KService::serviceByStorageId(args[0].toString());
         if (service) {
             d->init(service);
@@ -123,8 +121,8 @@ void AbstractRunner::performMatch(Plasma::RunnerContext &localContext)
         return;
     }
 
-    QTime time;
-    time.restart();
+    QElapsedTimer time;
+    time.start();
 
     //The local copy is already obtained in the job
     match(localContext);
@@ -382,7 +380,7 @@ void AbstractRunnerPrivate::init(const KService::Ptr service)
 
 void AbstractRunnerPrivate::init(const QString &path)
 {
-    runnerDescription = KPluginInfo(path + "/metadata.desktop");
+    runnerDescription = KPluginInfo(path + QStringLiteral("/metadata.desktop"));
     const QString api = runnerDescription.property(QStringLiteral("X-Plasma-API")).toString();
 }
 
